Skip to contents

Computes model predictions based exclusively on movement kernel variables (e.g. step length and turning angle), using the fitted coefficients from a conditional logistic regression model.

Usage

kernel_prediction(f, data, kernel_vars = c("step_length", "ta"), coefs)

Arguments

f

[formula]
Model formula, used to identify kernel variable terms.

data

[data.frame]
Data set on which predictions are made.

kernel_vars

[character=c("step_length","ta")]
Names of the movement kernel variables in the model.

coefs

[numeric]
Named numeric vector of fitted model coefficients.

Value

A numeric matrix of predicted values based on kernel variables only.