Private cabins vector data for the Hardangervidda wild reindeer area in Norway
Source:R/data.R
hardanger_cabins_private.gpkg.RdDataset containing the location of tourist private cabins in the surroundings of the Hardangervidda wild reindeer area. It corresponds to some specific building types (object_type = "Bygning", byggtyp_nbr = c("161", "162", "163")) from the public N50 dataset.
Format
A geopackage file. Projected CRS: ETRS89 / UTM zone 33N. The vector file presents the following columns:
gid: Line number, corresponding to the original dataset
buildtype: Type of building (code) in the original dataset
city: Code of the municipality where the cabin is located
value: Value 1, to be used for rasterization purposes
Examples
(f <- system.file("vector/hardanger_cabins_private.gpkg", package = "oneimpact"))
#> [1] "/home/runner/work/_temp/Library/oneimpact/vector/hardanger_cabins_private.gpkg"
sf::st_read(f)
#> Reading layer `hardanger_cabins_private' from data source
#> `/home/runner/work/_temp/Library/oneimpact/vector/hardanger_cabins_private.gpkg'
#> using driver `GPKG'
#> Simple feature collection with 38263 features and 4 fields
#> Geometry type: POINT
#> Dimension: XY
#> Bounding box: xmin: 5190.3 ymin: 6611728 xmax: 199271.3 ymax: 6759603
#> Projected CRS: ETRS89 / UTM zone 33N
# or
v <- terra::vect(f)
plot(v)